@@ -27,8 +27,8 @@
 #define _GNU_SOURCE 1
 
 #include <string.h>
-#include <rfb/rfb.h>
-#include <rfb/rfbregion.h>
+#include "rfb/rfb.h"
+#include "rfb/rfbregion.h"
 #include <netdb.h>
 
 #ifdef HAVE_FCNTL_H
@@ -74,7 +74,7 @@ rfbClientListInit(rfbScreenInfoPtr rfbScreen)
 {
     if(sizeof(rfbBool)!=1) {
         /* a sanity check */
-        fprintf(stderr,"rfbBool's size is not 1 (%d)!\n",sizeof(rfbBool));
+        fprintf(stderr,"rfbBool's size is not 1 (%lu)!\n",(unsigned long)sizeof(rfbBool));
 	/* we cannot continue, because rfbBool is supposed to be char everywhere */
 	exit(1);
     }
@@ -148,9 +148,10 @@ rfbNewClient(rfbScreenInfoPtr rfbScreen,
     rfbClientIteratorPtr iterator;
     rfbClientPtr cl,cl_;
     struct sockaddr_storage addr;
-    size_t addrlen = sizeof(addr);
+    socklen_t addrlen = sizeof(addr);
     int i;
     char host[NI_MAXHOST];
+    const char *prt = "unknown";
 
     cl = (rfbClientPtr)calloc(sizeof(rfbClientRec),1);
 
@@ -173,7 +174,12 @@ rfbNewClient(rfbScreenInfoPtr rfbScreen,
 
       cl->host = strdup(host);
 
-      rfbLog("Got connection from client %s\n", cl->host);
+      if (addr.ss_family == AF_INET)
+        prt = "IPv4";
+      else if (addr.ss_family == AF_INET6)
+        prt = "IPv6";
+
+      rfbLog("[%s] Got connection from client %s\n", prt, cl->host);
 
       rfbLog("  other clients:\n");
       iterator = rfbGetClientIterator(rfbScreen);
@@ -207,7 +213,7 @@ rfbNewClient(rfbScreenInfoPtr rfbScreen,
       cl->preferredEncoding = rfbEncodingRaw;
       cl->correMaxWidth = 48;
       cl->correMaxHeight = 48;
-#ifdef HAVE_LIBZ
+#ifdef VINO_HAVE_ZLIB
       cl->zrleData = NULL;
 #endif
 
@@ -234,7 +240,7 @@ rfbNewClient(rfbScreenInfoPtr rfbScreen,
       rfbScreen->rfbClientHead = cl;
       UNLOCK(rfbClientListMutex);
 
-#ifdef HAVE_LIBJPEG
+#ifdef VINO_HAVE_JPEG
       cl->tightCompressLevel = TIGHT_DEFAULT_COMPRESSION;
       cl->tightQualityLevel = -1;
       for (i = 0; i < 4; i++)
@@ -246,7 +252,7 @@ rfbNewClient(rfbScreenInfoPtr rfbScreen,
       cl->enableLastRectEncoding = FALSE;
       cl->useNewFBSize = FALSE;
 
-#ifdef HAVE_LIBZ
+#ifdef VINO_HAVE_ZLIB
       cl->compStreamInited = FALSE;
       cl->compStream.total_in = 0;
       cl->compStream.total_out = 0;
@@ -311,7 +317,7 @@ rfbClientConnectionGone(rfbClientPtr cl)
     if(cl->sock>0)
         close(cl->sock);
 
-#ifdef HAVE_LIBZ
+#ifdef VINO_HAVE_ZLIB
     FreeZrleData(cl);
 #endif
 
@@ -324,13 +330,13 @@ rfbClientConnectionGone(rfbClientPtr cl)
     rfbLog("Client %s gone\n",cl->host);
     free(cl->host);
 
-#ifdef HAVE_LIBZ
+#ifdef VINO_HAVE_ZLIB
     /* Release the compression state structures if any. */
     if ( cl->compStreamInited ) {
 	deflateEnd( &(cl->compStream) );
     }
 
-#ifdef HAVE_LIBJPEG
+#ifdef VINO_HAVE_JPEG
     for (i = 0; i < 4; i++) {
 	if (cl->zsActive[i])
 	    deflateEnd(&cl->zsStruct[i]);
@@ -660,10 +666,10 @@ rfbProcessClientNormalMessage(rfbClientPtr cl)
             case rfbEncodingRRE:
             case rfbEncodingCoRRE:
             case rfbEncodingHextile:
-#ifdef HAVE_LIBZ
+#ifdef VINO_HAVE_ZLIB
 	    case rfbEncodingZlib:
             case rfbEncodingZRLE:
-#ifdef HAVE_LIBJPEG
+#ifdef VINO_HAVE_JPEG
 	    case rfbEncodingTight:
 #endif
 #endif
@@ -698,11 +704,11 @@ rfbProcessClientNormalMessage(rfbClientPtr cl)
 		}
 		break;
             default:
-#ifdef HAVE_LIBZ
+#ifdef VINO_HAVE_ZLIB
 		if ( enc >= (uint32_t)rfbEncodingCompressLevel0 &&
 		     enc <= (uint32_t)rfbEncodingCompressLevel9 ) {
 		    cl->zlibCompressLevel = enc & 0x0F;
-#ifdef HAVE_LIBJPEG
+#ifdef VINO_HAVE_JPEG
 		    cl->tightCompressLevel = enc & 0x0F;
 		    rfbLog("Using compression level %d for client %s\n",
 			   cl->tightCompressLevel, cl->host);
@@ -992,6 +998,8 @@ rfbSendFramebufferUpdate(rfbClientPtr cl,
 	    rfbDrawCursor(cl->screen, &cursorBounds);
 	    cursorIsDrawn = TRUE;
 
+	    cl->cursorWasMoved = FALSE;
+	    cl->cursorWasChanged = FALSE;
 	    cl->lastDrawnCursorBounds = cursorBounds;
 
 	    sraRgnOr(cl->modifiedRegion, cursorRegion);
@@ -1066,7 +1074,7 @@ rfbSendFramebufferUpdate(rfbClientPtr cl,
                                      * ((h-1) / cl->correMaxHeight + 1));
         }
 	sraRgnReleaseIterator(i);
-#ifdef HAVE_LIBZ
+#ifdef VINO_HAVE_ZLIB
     } else if (cl->preferredEncoding == rfbEncodingZlib) {
 	nUpdateRegionRects = 0;
 
@@ -1077,7 +1085,7 @@ rfbSendFramebufferUpdate(rfbClientPtr cl,
             int h = rect.y2 - y;
 	    nUpdateRegionRects += (((h-1) / (ZLIB_MAX_SIZE( w ) / w)) + 1);
 	}
-#ifdef HAVE_LIBJPEG
+#ifdef VINO_HAVE_JPEG
     } else if (cl->preferredEncoding == rfbEncodingTight) {
 	nUpdateRegionRects = 0;
 
@@ -1105,14 +1113,14 @@ rfbSendFramebufferUpdate(rfbClientPtr cl,
 	if(cl->screen->maxRectsPerUpdate>0
 	   /* CoRRE splits the screen into smaller squares */
 	   && cl->preferredEncoding != rfbEncodingCoRRE
-#ifdef HAVE_LIBZ
+#ifdef VINO_HAVE_ZLIB
 	   /* Zlib encoding splits rectangles up into smaller chunks */
 	   && cl->preferredEncoding != rfbEncodingZlib
-#ifdef HAVE_LIBJPEG
+#ifdef VINO_HAVE_JPEG
 	   /* Tight encoding counts the rectangles differently */
 	   && cl->preferredEncoding != rfbEncodingTight
 #endif
-#endif /* HAVE_LIBZ */
+#endif /* VINO_HAVE_ZLIB */
 	   && nUpdateRegionRects>cl->screen->maxRectsPerUpdate) {
 	    sraRegion* newUpdateRegion = sraRgnBBox(updateRegion);
 	    sraRgnDestroy(updateRegion);
@@ -1172,19 +1180,19 @@ rfbSendFramebufferUpdate(rfbClientPtr cl,
             if (!rfbSendRectEncodingHextile(cl, x, y, w, h))
 		goto tx_error;
             break;
-#ifdef HAVE_LIBZ
+#ifdef VINO_HAVE_ZLIB
 	case rfbEncodingZlib:
 	    if (!rfbSendRectEncodingZlib(cl, x, y, w, h))
 		goto tx_error;
 	    break;
-#ifdef HAVE_LIBJPEG
+#ifdef VINO_HAVE_JPEG
 	case rfbEncodingTight:
 	    if (!rfbSendRectEncodingTight(cl, x, y, w, h))
 		goto tx_error;
 	    break;
 #endif
 #endif
-#ifdef HAVE_LIBZ
+#ifdef VINO_HAVE_ZLIB
        case rfbEncodingZRLE:
            if (!rfbSendRectEncodingZRLE(cl, x, y, w, h))
 	       goto tx_error;
